searchData={"items":[{"type":"module","title":"Tezex.Crypto","doc":"Provides cryptographic functions for Tezos blockchain operations.\n\nThis module includes functions to:\n- Check Tezos signed messages\n- Derive public key hashes (pkh) from public keys\n- Verify that a public key corresponds to a wallet address (public key hash)\n- Sign messages and operations\n- Encode and decode various Tezos-specific data formats","ref":"Tezex.Crypto.html"},{"type":"function","title":"Tezex.Crypto.check_address/2","doc":"Verify that `address` is the public key hash of `pubkey`.","ref":"Tezex.Crypto.html#check_address/2"},{"type":"function","title":"Examples - Tezex.Crypto.check_address/2","doc":"iex> pubkey = \"sppk7aBerAEA6tv4wzg6FnK7i5YrGtEGFVvNjWhc2QX8bhzpouBVFSW\"\n    iex> check_address(\"tz2BC83pvEAag6r2ZV7kPghNAbjFoiqhCvZx\", pubkey)\n    :ok\n    iex> check_address(\"tz1burnburnburnburnburnburnburjAYjjX\", pubkey)\n    {:error, :address_mismatch}\n    iex> check_address(\"tz2BC83pvEAag6r2ZV7kPghNAbjFoiqhCvZx\", \"x\" <> pubkey)\n    {:error, :invalid_pubkey_format}","ref":"Tezex.Crypto.html#check_address/2-examples"},{"type":"function","title":"Tezex.Crypto.check_signature/4","doc":"Verify that `address` is the public key hash of `pubkey` and that `signature` is a valid signature for `message` signed with the private key corresponding to public key `pubkey`.","ref":"Tezex.Crypto.html#check_signature/4"},{"type":"function","title":"Examples - Tezex.Crypto.check_signature/4","doc":"iex> address = \"tz2BC83pvEAag6r2ZV7kPghNAbjFoiqhCvZx\"\n    iex> address_b = \"tz1burnburnburnburnburnburnburjAYjjX\"\n    iex> signature = \"spsig1ZNQaUKNERZSiEiNviqa5EAPkcNASXhfkXtxRatZTDZAnUB4Ra2Jus8b1oEpFnPx8Z6g28pd8vK3R8nPK29JDU5FiSLH5T\"\n    iex> message = \"05010000007154657a6f73205369676e6564204d6573736167653a207369676e206d6520696e20617320747a32424338337076454161673672325a56376b5067684e41626a466f69716843765a78206f6e206f626a6b742e636f6d20617420323032312d31302d30345431383a35393a31332e3939305a\"\n    iex> public_key = \"sppk7aBerAEA6tv4wzg6FnK7i5YrGtEGFVvNjWhc2QX8bhzpouBVFSW\"\n    iex> check_signature(address, signature, message, public_key)\n    :ok\n    iex> check_signature(address_b, signature, message, public_key)\n    {:error, :address_mismatch}\n    iex> check_signature(address, signature, \"\", public_key)\n    {:error, :bad_signature}\n    iex> check_signature(address, \"x\" <> signature, \"\", public_key)\n    {:error, :invalid_signature}","ref":"Tezex.Crypto.html#check_signature/4-examples"},{"type":"function","title":"Tezex.Crypto.decode_signature/1","doc":"","ref":"Tezex.Crypto.html#decode_signature/1"},{"type":"function","title":"Tezex.Crypto.decode_signature!/1","doc":"","ref":"Tezex.Crypto.html#decode_signature!/1"},{"type":"function","title":"Tezex.Crypto.derive_address/1","doc":"Derive public key hash (Tezos wallet address) from public key","ref":"Tezex.Crypto.html#derive_address/1"},{"type":"function","title":"Examples - Tezex.Crypto.derive_address/1","doc":"iex> derive_address(\"edpktsPhZ8weLEXqf4Fo5FS9Qx8ZuX4QpEBEwe63L747G8iDjTAF6w\")\n    {:ok, \"tz1LKpeN8ZSSFNyTWiBNaE4u4sjaq7J1Vz2z\"}\n    iex> derive_address(\"sppk7aBerAEA6tv4wzg6FnK7i5YrGtEGFVvNjWhc2QX8bhzpouBVFSW\")\n    {:ok, \"tz2BC83pvEAag6r2ZV7kPghNAbjFoiqhCvZx\"}\n    iex> derive_address(\"p2pk65yRxCX65k6qRPrbqGWvfW5JnLB1p3dn1oM5o9cyqLKPPhJaBMa\")\n    {:ok, \"tz3bPFa6mGv8m4Ppn7w5KSDyAbEPwbJNpC9p\"}\n    iex> derive_address(\"_p2pk65yRxCX65k6qRPrbqGWvfW5JnLB1p3dn1oM5o9cyqLKPPhJaBMa\")\n    {:error, :invalid_pubkey_format}\n    iex> derive_address(\"p2pk65yRxCX65k6\")\n    {:error, :invalid_pubkey_format}","ref":"Tezex.Crypto.html#derive_address/1-examples"},{"type":"function","title":"Tezex.Crypto.encode_pubkey/2","doc":"Encode a raw public key","ref":"Tezex.Crypto.html#encode_pubkey/2"},{"type":"function","title":"Examples - Tezex.Crypto.encode_pubkey/2","doc":"iex> encode_pubkey(\"tz1LPggcEZincSDQJUXrskwJPif4aJhWxMjd\", \"52d396892b2489ec91406f83680b172b5ca42f606128cd4c44ea4d09d31aa524\")\n    {:ok, \"edpkuGhdSSNgqT92Gwoxt9vV3TmpQE93TtQSn5kkyULCh7cfeQFTno\"}\n    iex> encode_pubkey(\"tz1LPggcEZincSDQJUXrskwJPif4aJhWxMjd\", \"foo\")\n    :error","ref":"Tezex.Crypto.html#encode_pubkey/2-examples"},{"type":"function","title":"Tezex.Crypto.extract_pubkey/1","doc":"","ref":"Tezex.Crypto.html#extract_pubkey/1"},{"type":"function","title":"Tezex.Crypto.sign/3","doc":"","ref":"Tezex.Crypto.html#sign/3"},{"type":"function","title":"Tezex.Crypto.sign_message/2","doc":"Sign the hexadecimal/Micheline representation of a string, Micheline encoding is done when `bytes` do not start with `\"0501\"`.","ref":"Tezex.Crypto.html#sign_message/2"},{"type":"function","title":"Examples - Tezex.Crypto.sign_message/2","doc":"iex> encoded_private_key = \"spsk24EJohZHJkZnWEzj3w9wE7BFARpFmq5WAo9oTtqjdJ2t4pyoB3\"\n    iex> sign_message(encoded_private_key, \"foo\")\n    \"spsig1Uyadmsz75zND5qDjSAteir1NGCEuPaxNnT8QmXkwCJkuzWUyxKqKsjSx3nU4uj2nk8t31VFFhQ4YsPKdZ9ghA2d2fe9HF\"\n    iex> msg = Tezex.Micheline.pack(\"foo\", :string)\n    \"050100000003666f6f\"\n    iex> sign_message(encoded_private_key, msg)\n    \"spsig1Uyadmsz75zND5qDjSAteir1NGCEuPaxNnT8QmXkwCJkuzWUyxKqKsjSx3nU4uj2nk8t31VFFhQ4YsPKdZ9ghA2d2fe9HF\"","ref":"Tezex.Crypto.html#sign_message/2-examples"},{"type":"function","title":"Tezex.Crypto.sign_operation/2","doc":"Sign an operation using `0x03` as watermark","ref":"Tezex.Crypto.html#sign_operation/2"},{"type":"function","title":"Tezex.Crypto.validate_address/1","doc":"Validate an implicit account address","ref":"Tezex.Crypto.html#validate_address/1"},{"type":"function","title":"Examples - Tezex.Crypto.validate_address/1","doc":"iex> validate_address(\"tz1L9r8mWmRpndRhuvMCWESLGSVeFzQ9NAWx\")\n    {:error, :invalid_checksum}\n    iex> validate_address(\"tz3bPFa6mGv8m4Ppn7w5KSD00bEPwbJNpC9p\")\n    {:error, :invalid_base58}\n    iex> validate_address(\"tz1L9r8mWmRpndRhuvMCWESLGSVeFz\")\n    {:error, :invalid_length}\n    iex> validate_address(\"tp3bPFa6mGv8m4Ppn7w5KSDyAbEPwbJNpC9p\")\n    {:error, :invalid_prefix}\n    iex> validate_address(\"tz3bPFa6mGv8m4Ppn7w5KSDyAbEPwbJNpC9p\")\n    :ok","ref":"Tezex.Crypto.html#validate_address/1-examples"},{"type":"function","title":"Tezex.Crypto.verify_signature/3","doc":"Verify that `signature` is a valid signature for `message` signed with the private key corresponding to public key `pubkey`","ref":"Tezex.Crypto.html#verify_signature/3"},{"type":"type","title":"Tezex.Crypto.privkey_param/0","doc":"Represents a private key parameter.\nIt can be either a binary string (the private key itself) or a tuple containing the private key and a passphrase.","ref":"Tezex.Crypto.html#t:privkey_param/0"},{"type":"type","title":"Tezex.Crypto.signature_verification_result/0","doc":"Represents the result of a signature verification operation.\nIt can be either `:ok` if the signature is valid, or an error tuple with a specific reason.","ref":"Tezex.Crypto.html#t:signature_verification_result/0"},{"type":"module","title":"Tezex.Crypto.Base58Check","doc":"Base58Check encoding/decoding utils","ref":"Tezex.Crypto.Base58Check.html"},{"type":"function","title":"Tezex.Crypto.Base58Check.decode58/1","doc":"","ref":"Tezex.Crypto.Base58Check.html#decode58/1"},{"type":"function","title":"Tezex.Crypto.Base58Check.decode58!/1","doc":"Decodes the given string.","ref":"Tezex.Crypto.Base58Check.html#decode58!/1"},{"type":"function","title":"Examples - Tezex.Crypto.Base58Check.decode58!/1","doc":"iex> decode58!(\"1\")\n    <<0>>\n    iex> decode58!(\"z\")\n    <<57>>\n    iex> decode58!(\"Jf\")\n    :binary.encode_unsigned(1024)\n    iex> decode58!(\"BukQL\")\n    :binary.encode_unsigned(123_456_789)","ref":"Tezex.Crypto.Base58Check.html#decode58!/1-examples"},{"type":"function","title":"Tezex.Crypto.Base58Check.decode58check!/1","doc":"","ref":"Tezex.Crypto.Base58Check.html#decode58check!/1"},{"type":"function","title":"Tezex.Crypto.Base58Check.encode/2","doc":"Prepends `prefix` to `payload`, computes its checksum (double sha256) and encodes in Base58.","ref":"Tezex.Crypto.Base58Check.html#encode/2"},{"type":"function","title":"Examples - Tezex.Crypto.Base58Check.encode/2","doc":"iex> encode(<<165, 37, 29, 103, 204, 101, 232, 200, 87, 148, 178, 91, 43, 72, 191, 252, 190, 134, 75, 170>>, <<6, 161, 164>>)\n    \"tz3bPFa6mGv8m4Ppn7w5KSDyAbEPwbJNpC9p\"","ref":"Tezex.Crypto.Base58Check.html#encode/2-examples"},{"type":"module","title":"Tezex.Crypto.Curve","doc":"Specific elliptic curve data.\n\nParameters:\n  - `:A` [`t:non_neg_integer/0`]: angular coefficient of x in the curve equation. ex: 123\n  - `:B` [`t:non_neg_integer/0`]: linear coefficient of x in the curve equation. ex: 123\n  - `:P` [`t:non_neg_integer/0`]: curve modulo. ex: 12345\n  - `:N` [`t:non_neg_integer/0`]: curve order. ex: 12345\n  - `:G` [`t:Tezex.Crypto.Point.t/0`]: EC Point corresponding to the public key. ex: `%Tezex.Crypto.Point{x: 123, y: 456}`\n  - `:name` [`t:atom/0`]: curve name. ex: :secp256k1","ref":"Tezex.Crypto.Curve.html"},{"type":"function","title":"Tezex.Crypto.Curve.contains?/2","doc":"Verifies if the point `p` is on the curve using the elliptic curve equation:\ny^2 = x^3 + A*x + B (mod P)\n\nParameters:\n- `curve` [`t:Tezex.Crypto.Curve.t/0`]: curve data\n- `p` [`t:Tezex.Crypto.Point.t/0`]: curve point\n\nReturns:\n- `result` [`t:boolean/0`]: true if point is on the curve, false otherwise","ref":"Tezex.Crypto.Curve.html#contains?/2"},{"type":"function","title":"Tezex.Crypto.Curve.get_length/1","doc":"Get the curve length\n\nParameters:\n- `curve` [`t:Tezex.Crypto.Curve.t/0`]: curve data\n\nReturns:\n- `length` [`t:non_neg_integer/0`]: curve length","ref":"Tezex.Crypto.Curve.html#get_length/1"},{"type":"type","title":"Tezex.Crypto.Curve.t/0","doc":"","ref":"Tezex.Crypto.Curve.html#t:t/0"},{"type":"module","title":"Tezex.Crypto.ECDSA","doc":"Elliptic Curve Digital Signature Algorithm (ECDSA) implementation to:\n- decode compressed public key\n- verify signatures\n- sign bytes","ref":"Tezex.Crypto.ECDSA.html"},{"type":"function","title":"Tezex.Crypto.ECDSA.decode_point/2","doc":"","ref":"Tezex.Crypto.ECDSA.html#decode_point/2"},{"type":"function","title":"Tezex.Crypto.ECDSA.decode_public_key/2","doc":"Decodes a compressed public key to the EC public key it is representing on EC `curve`.\n\nHere is a sample `curve`, P-256 with curve parameters from  :\n\n```elixir\n%Curve{\n    name: :prime256v1,\n    A: 0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFC,\n    B: 0x5AC635D8AA3A93E7B3EBBD55769886BC651D06B0CC53B0F63BCE3C3E27D2604B,\n    P: 0xFFFFFFFF00000001000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF,\n    N: 0xFFFFFFFF00000000FFFFFFFFFFFFFFFFBCE6FAADA7179E84F3B9CAC2FC632551,\n    G: %Point{\n      x: 0x6B17D1F2E12C4247F8BCE6E563A440F277037D812DEB33A0F4A13945D898C296,\n      y: 0x4FE342E2FE1A7F9B8EE7EB4A7C0F9E162BCE33576B315ECECBB6406837BF51F5\n    }\n  }\n```\n\nParameters:\n- `compressed_pubkey` [`t:binary/0`]: the public key to decode\n- `curve` [`t:Tezex.Crypto.Curve.t/0`]: the curve to use (or one of `:prime256v1`, `:secp256k1` for the two known curves supported by default)\n\nReturns:\n- public_key [`t:Tezex.Crypto.PublicKey.t/0`]: a struct containing the public point and the curve;","ref":"Tezex.Crypto.ECDSA.html#decode_public_key/2"},{"type":"function","title":"Tezex.Crypto.ECDSA.sign/3","doc":"","ref":"Tezex.Crypto.ECDSA.html#sign/3"},{"type":"function","title":"Tezex.Crypto.ECDSA.verify?/4","doc":"Verifies a message signature based on a public key\n\nParameters:\n- `message` [`t:binary/0`]: message that was signed\n- `signature` [`t:Tezex.Crypto.Signature.t/0`]: signature associated with the message\n- `public_key` [`t:Tezex.Crypto.PublicKey.t/0`]: public key associated with the message signer\n- `options` [`kw list`]: refines request\n  - `:hashfunc` [`fun/1`]: hash function applied to the message. Default: `fn msg -> :crypto.hash(:sha256, msg) end`\n\nReturns:\n- verified [`t:boolean/0`]: true if message, public key and signature are compatible, false otherwise","ref":"Tezex.Crypto.ECDSA.html#verify?/4"},{"type":"module","title":"Tezex.Crypto.HMACDRBG","doc":"Pure Elixir implementation of [HMAC-DRBG](https://csrc.nist.gov/csrc/media/events/random-number-generation-workshop-2004/documents/hashblockcipherdrbg.pdf)\n\nUsage:\n```\nentropy = \"totally random0123456789\"\nnonce = \"some secret nonce\"\npers = \"my drbg\"\ndrbg = HMACDRBG.init(entropy, nonce, pers)\n\n{_result, drbg} = HMACDRBG.generate(drbg, 32)\n{_result, drbg} = HMACDRBG.generate(drbg, 32)\n{result, drbg} = HMACDRBG.generate(drbg, 32)\n\nBase16.encode(result, case: :lower) == \"a00cb0982eec3917b4b48abccfd460366d98b887943ff402bb7147cda174a46f\"\n```\n\nImplementation inspired by both:\n\n> https://github.com/indutny/hmac-drbg/blob/master/package.json\n>\n> MIT / (c) Fedor Indutny  \n\n> https://github.com/sorpaas/rust-hmac-drbg/blob/master/src/lib.rs\n>\n> Apache License, Version 2.0, January 2004 / Copyright {yyyy} {name of copyright owner}","ref":"Tezex.Crypto.HMACDRBG.html"},{"type":"function","title":"Tezex.Crypto.HMACDRBG.generate/3","doc":"Generate `size` bytes, returning the generated bytes and the updated DRBG","ref":"Tezex.Crypto.HMACDRBG.html#generate/3"},{"type":"function","title":"Tezex.Crypto.HMACDRBG.init/4","doc":"Initialize a DRBG","ref":"Tezex.Crypto.HMACDRBG.html#init/4"},{"type":"function","title":"Tezex.Crypto.HMACDRBG.reseed/3","doc":"Reseed a DRBG","ref":"Tezex.Crypto.HMACDRBG.html#reseed/3"},{"type":"type","title":"Tezex.Crypto.HMACDRBG.hash_algo/0","doc":"","ref":"Tezex.Crypto.HMACDRBG.html#t:hash_algo/0"},{"type":"type","title":"Tezex.Crypto.HMACDRBG.t/0","doc":"","ref":"Tezex.Crypto.HMACDRBG.html#t:t/0"},{"type":"module","title":"Tezex.Crypto.KnownCurves","doc":"The supported elliptic curves","ref":"Tezex.Crypto.KnownCurves.html"},{"type":"function","title":"Tezex.Crypto.KnownCurves.get_curve_by_name/1","doc":"","ref":"Tezex.Crypto.KnownCurves.html#get_curve_by_name/1"},{"type":"function","title":"Tezex.Crypto.KnownCurves.prime256v1/0","doc":"","ref":"Tezex.Crypto.KnownCurves.html#prime256v1/0"},{"type":"function","title":"Tezex.Crypto.KnownCurves.secp256k1/0","doc":"","ref":"Tezex.Crypto.KnownCurves.html#secp256k1/0"},{"type":"module","title":"Tezex.Crypto.Point","doc":"Holds point data. Is usually handled internally by the library and serves only as detailed information to the end-user.\n\nParameters:\n- `:x` [`t:non_neg_integer/0`]: first point coordinate;\n- `:y` [`t:non_neg_integer/0`]: first point coordinate;\n- `:z` [`t:non_neg_integer/0`]: first point coordinate (used only in Jacobian coordinates);","ref":"Tezex.Crypto.Point.html"},{"type":"function","title":"Tezex.Crypto.Point.is_at_infinity?/1","doc":"","ref":"Tezex.Crypto.Point.html#is_at_infinity?/1"},{"type":"type","title":"Tezex.Crypto.Point.t/0","doc":"","ref":"Tezex.Crypto.Point.html#t:t/0"},{"type":"module","title":"Tezex.Crypto.PrivateKey","doc":"Holds private key data.\n\nUsed to create private keys and created public keys from private keys.\n\nParameters:\n- `:secret` [`t:binary/0`]: public key point data;\n- `:curve` [`t:Tezex.Crypto.Curve.t/0`]: public key curve information.","ref":"Tezex.Crypto.PrivateKey.html"},{"type":"function","title":"Tezex.Crypto.PrivateKey.__struct__/0","doc":"Holds private key data.\n\nParameters:\n- `:secret` [`t:binary/0`]: private key secret number as bytes\n- `:curve` [`t:Tezex.Crypto.Curve.t/0`]: private key curve information","ref":"Tezex.Crypto.PrivateKey.html#__struct__/0"},{"type":"function","title":"Tezex.Crypto.PrivateKey.generate/2","doc":"Creates a new private key\n\nParameters:\n- `secret` [`t:binary/0`]: private key secret. Default: nil -> random key will be generated\n- `curve_name` [`t:atom/0`]: curve name. Default: :secp256k1\n\nReturns:\n- `private_key` [`t:Tezex.Crypto.PrivateKey.t/0`]: private key struct","ref":"Tezex.Crypto.PrivateKey.html#generate/2"},{"type":"function","title":"Example: - Tezex.Crypto.PrivateKey.generate/2","doc":"iex> Tezex.Crypto.PrivateKey.generate()\n    %Tezex.Crypto.PrivateKey{...}","ref":"Tezex.Crypto.PrivateKey.html#generate/2-example"},{"type":"function","title":"Tezex.Crypto.PrivateKey.get_public_key/1","doc":"Gets the public key associated with a private key\n\nParameters:\n- `private_key` [`t:Tezex.Crypto.PrivateKey.t/0`]: private key struct\n\nReturns:\n- `public_key` [`t:Tezex.Crypto.PublicKey.t/0`]: public key struct","ref":"Tezex.Crypto.PrivateKey.html#get_public_key/1"},{"type":"function","title":"Example: - Tezex.Crypto.PrivateKey.get_public_key/1","doc":"iex> Tezex.Crypto.PrivateKey.get_public_key(private_key)\n    %Tezex.Crypto.PublicKey{...}","ref":"Tezex.Crypto.PrivateKey.html#get_public_key/1-example"},{"type":"type","title":"Tezex.Crypto.PrivateKey.t/0","doc":"","ref":"Tezex.Crypto.PrivateKey.html#t:t/0"},{"type":"module","title":"Tezex.Crypto.PublicKey","doc":"Holds public key data.\n\nParameters:\n- `:point` [`t:Tezex.Crypto.Point.t/0`]: public key point data;\n- `:curve` [`t:Tezex.Crypto.Curve.t/0`]: public key curve information.","ref":"Tezex.Crypto.PublicKey.html"},{"type":"type","title":"Tezex.Crypto.PublicKey.t/0","doc":"","ref":"Tezex.Crypto.PublicKey.html#t:t/0"},{"type":"module","title":"Tezex.Crypto.Signature","doc":"Holds signature data.\n\nParameters:\n- `:r` [`t:pos_integer/0`]: first signature number;\n- `:s` [`t:pos_integer/0`]: second signature number.","ref":"Tezex.Crypto.Signature.html"},{"type":"type","title":"Tezex.Crypto.Signature.t/0","doc":"","ref":"Tezex.Crypto.Signature.html#t:t/0"},{"type":"module","title":"Tezex.Fee","doc":"","ref":"Tezex.Fee.html"},{"type":"function","title":"Tezex.Fee.calculate_fee/3","doc":"","ref":"Tezex.Fee.html#calculate_fee/3"},{"type":"function","title":"Tezex.Fee.default_gas_limit/1","doc":"","ref":"Tezex.Fee.html#default_gas_limit/1"},{"type":"function","title":"Tezex.Fee.default_gas_reserve/0","doc":"","ref":"Tezex.Fee.html#default_gas_reserve/0"},{"type":"function","title":"Tezex.Fee.default_storage_limit/1","doc":"","ref":"Tezex.Fee.html#default_storage_limit/1"},{"type":"function","title":"Tezex.Fee.extra_size/0","doc":"","ref":"Tezex.Fee.html#extra_size/0"},{"type":"function","title":"Tezex.Fee.hard_gas_limit_per_operation/0","doc":"","ref":"Tezex.Fee.html#hard_gas_limit_per_operation/0"},{"type":"function","title":"Tezex.Fee.hard_storage_limit_per_operation/0","doc":"","ref":"Tezex.Fee.html#hard_storage_limit_per_operation/0"},{"type":"module","title":"Tezex.Forge","doc":"Convert Tezos Micheline data from/to binary form for injection into the Tezos blockchain (aka forging/unforging Micheline).\n\nMostly ported from pytezos@9352c4579e436b92f8070343964af20747255197\n> pytezos / MIT License / (c) 2020 Baking Bad / (c) 2018 Arthur Breitman","ref":"Tezex.Forge.html"},{"type":"function","title":"Tezex.Forge.forge_address/3","doc":"Encode address or key hash into bytes.\n\n- `value` is a base58 encoded address or key_hash\n- `tz_only` indicates that it's a key_hash (will be encoded in a more compact form)","ref":"Tezex.Forge.html#forge_address/3"},{"type":"function","title":"Tezex.Forge.forge_array/3","doc":"","ref":"Tezex.Forge.html#forge_array/3"},{"type":"function","title":"Tezex.Forge.forge_base58/2","doc":"","ref":"Tezex.Forge.html#forge_base58/2"},{"type":"function","title":"Tezex.Forge.forge_bool/2","doc":"","ref":"Tezex.Forge.html#forge_bool/2"},{"type":"function","title":"Tezex.Forge.forge_contract/2","doc":"","ref":"Tezex.Forge.html#forge_contract/2"},{"type":"function","title":"Tezex.Forge.forge_int16/2","doc":"","ref":"Tezex.Forge.html#forge_int16/2"},{"type":"function","title":"Tezex.Forge.forge_int32/2","doc":"","ref":"Tezex.Forge.html#forge_int32/2"},{"type":"function","title":"Tezex.Forge.forge_int/2","doc":"Encodes a signed unbounded integer into byte form.","ref":"Tezex.Forge.html#forge_int/2"},{"type":"function","title":"Parameters - Tezex.Forge.forge_int/2","doc":"* `value` - The integer to be encoded.\n  * `output_encoding` - The encoding type for the output. Defaults to `:bytes`.","ref":"Tezex.Forge.html#forge_int/2-parameters"},{"type":"function","title":"Returns - Tezex.Forge.forge_int/2","doc":"A binary string representing the encoded integer.","ref":"Tezex.Forge.html#forge_int/2-returns"},{"type":"function","title":"Examples - Tezex.Forge.forge_int/2","doc":"iex> forge_int(123)\n    <<123>>\n\n    iex> forge_int(123, :hex)\n    \"7B\"","ref":"Tezex.Forge.html#forge_int/2-examples"},{"type":"function","title":"Tezex.Forge.forge_micheline/2","doc":"Encode a Micheline expression into byte form.","ref":"Tezex.Forge.html#forge_micheline/2"},{"type":"function","title":"Tezex.Forge.forge_nat/2","doc":"Encode a non-negative integer using LEB128 encoding.","ref":"Tezex.Forge.html#forge_nat/2"},{"type":"function","title":"Tezex.Forge.forge_public_key/2","doc":"","ref":"Tezex.Forge.html#forge_public_key/2"},{"type":"function","title":"Tezex.Forge.forge_script/2","doc":"","ref":"Tezex.Forge.html#forge_script/2"},{"type":"function","title":"Tezex.Forge.forge_script_expr/2","doc":"","ref":"Tezex.Forge.html#forge_script_expr/2"},{"type":"function","title":"Tezex.Forge.optimize_timestamp/1","doc":"","ref":"Tezex.Forge.html#optimize_timestamp/1"},{"type":"function","title":"Tezex.Forge.unforge_address/2","doc":"","ref":"Tezex.Forge.html#unforge_address/2"},{"type":"function","title":"Tezex.Forge.unforge_array/3","doc":"","ref":"Tezex.Forge.html#unforge_array/3"},{"type":"function","title":"Tezex.Forge.unforge_chain_id/2","doc":"","ref":"Tezex.Forge.html#unforge_chain_id/2"},{"type":"function","title":"Tezex.Forge.unforge_contract/2","doc":"Decode a contract (address + optional entrypoint) from bytes, returning a string with the base58 encoded address and, if present, the entrypoint separated by `%`.","ref":"Tezex.Forge.html#unforge_contract/2"},{"type":"function","title":"Tezex.Forge.unforge_int/2","doc":"Decode a signed unbounded integer from bytes.","ref":"Tezex.Forge.html#unforge_int/2"},{"type":"function","title":"Tezex.Forge.unforge_micheline/2","doc":"Parse Micheline map from bytes.","ref":"Tezex.Forge.html#unforge_micheline/2"},{"type":"function","title":"Tezex.Forge.unforge_public_key/2","doc":"","ref":"Tezex.Forge.html#unforge_public_key/2"},{"type":"function","title":"Tezex.Forge.unforge_signature/2","doc":"","ref":"Tezex.Forge.html#unforge_signature/2"},{"type":"type","title":"Tezex.Forge.base58_encoding/0","doc":"Represents a base58 encoding configuration.","ref":"Tezex.Forge.html#t:base58_encoding/0"},{"type":"type","title":"Tezex.Forge.io_encoding/0","doc":"Represents the encoding type for input/output operations.\nCan be either `:bytes` for raw binary data or `:hex` for hexadecimal string representation.","ref":"Tezex.Forge.html#t:io_encoding/0"},{"type":"module","title":"Tezex.ForgeOperation","doc":"Prepare an operation or an operation group for injection into the Tezos blockchain.\n\nMostly ported from pytezos@9352c4579e436b92f8070343964af20747255197\n> pytezos / MIT License / (c) 2020 Baking Bad / (c) 2018 Arthur Breitman","ref":"Tezex.ForgeOperation.html"},{"type":"function","title":"Tezex.ForgeOperation.activate_account/1","doc":"","ref":"Tezex.ForgeOperation.html#activate_account/1"},{"type":"function","title":"Tezex.ForgeOperation.delegation/1","doc":"","ref":"Tezex.ForgeOperation.html#delegation/1"},{"type":"function","title":"Tezex.ForgeOperation.endorsement/1","doc":"","ref":"Tezex.ForgeOperation.html#endorsement/1"},{"type":"function","title":"Tezex.ForgeOperation.endorsement_with_slot/1","doc":"","ref":"Tezex.ForgeOperation.html#endorsement_with_slot/1"},{"type":"function","title":"Tezex.ForgeOperation.entrypoint/1","doc":"","ref":"Tezex.ForgeOperation.html#entrypoint/1"},{"type":"function","title":"Tezex.ForgeOperation.failing_noop/1","doc":"","ref":"Tezex.ForgeOperation.html#failing_noop/1"},{"type":"function","title":"Tezex.ForgeOperation.inline_endorsement/1","doc":"","ref":"Tezex.ForgeOperation.html#inline_endorsement/1"},{"type":"function","title":"Tezex.ForgeOperation.operation/1","doc":"","ref":"Tezex.ForgeOperation.html#operation/1"},{"type":"function","title":"Tezex.ForgeOperation.operation_group/1","doc":"","ref":"Tezex.ForgeOperation.html#operation_group/1"},{"type":"function","title":"Tezex.ForgeOperation.origination/1","doc":"","ref":"Tezex.ForgeOperation.html#origination/1"},{"type":"function","title":"Tezex.ForgeOperation.register_global_constant/1","doc":"","ref":"Tezex.ForgeOperation.html#register_global_constant/1"},{"type":"function","title":"Tezex.ForgeOperation.reveal/1","doc":"","ref":"Tezex.ForgeOperation.html#reveal/1"},{"type":"function","title":"Tezex.ForgeOperation.smart_rollup_add_messages/1","doc":"","ref":"Tezex.ForgeOperation.html#smart_rollup_add_messages/1"},{"type":"function","title":"Tezex.ForgeOperation.smart_rollup_execute_outbox_message/1","doc":"","ref":"Tezex.ForgeOperation.html#smart_rollup_execute_outbox_message/1"},{"type":"function","title":"Tezex.ForgeOperation.transaction/1","doc":"","ref":"Tezex.ForgeOperation.html#transaction/1"},{"type":"function","title":"Tezex.ForgeOperation.transfer_ticket/1","doc":"","ref":"Tezex.ForgeOperation.html#transfer_ticket/1"},{"type":"function","title":"Tezex.ForgeOperation.validate_required_keys/3","doc":"","ref":"Tezex.ForgeOperation.html#validate_required_keys/3"},{"type":"module","title":"Tezex.Micheline","doc":"Serialize/deserialize data to/from Tezos Micheline optimized binary representation.","ref":"Tezex.Micheline.html"},{"type":"function","title":"Tezex.Micheline.pack/2","doc":"Serialize a piece of data to its optimized binary representation.","ref":"Tezex.Micheline.html#pack/2"},{"type":"function","title":"Examples - Tezex.Micheline.pack/2","doc":"iex> pack(-6407, :int)\n    \"0500c764\"\n    iex> pack(%{\"prim\" => \"Pair\", \"args\" => [%{\"int\" => \"-33\"}, %{\"int\" => \"71\"}]})\n    \"0507070061008701\"","ref":"Tezex.Micheline.html#pack/2-examples"},{"type":"function","title":"Tezex.Micheline.unpack/2","doc":"Deserialize a piece of data from its optimized binary representation.","ref":"Tezex.Micheline.html#unpack/2"},{"type":"function","title":"Examples - Tezex.Micheline.unpack/2","doc":"iex> unpack(\"050a0000001601e67bac124dff100a57644de0cf26d341ebf9492600\", :address)\n    \"KT1VbT8n6YbrzPSjdAscKfJGDDNafB5yHn1H\"\n    iex> unpack(\"0507070001000c\")\n    %{\"prim\" => \"Pair\", \"args\" => [%{\"int\" => \"1\"}, %{\"int\" => \"12\"}]}","ref":"Tezex.Micheline.html#unpack/2-examples"},{"type":"type","title":"Tezex.Micheline.pack_types/0","doc":"","ref":"Tezex.Micheline.html#t:pack_types/0"},{"type":"type","title":"Tezex.Micheline.unpack_result/0","doc":"","ref":"Tezex.Micheline.html#t:unpack_result/0"},{"type":"module","title":"Tezex.Rpc","doc":"Send transactions to the Tezos network.\n\n`send_operation/4` is the main function, see tests for usage.","ref":"Tezex.Rpc.html"},{"type":"function","title":"Tezex.Rpc.fill_operation_fee/3","doc":"","ref":"Tezex.Rpc.html#fill_operation_fee/3"},{"type":"function","title":"Tezex.Rpc.forge_and_sign_operation/2","doc":"Sign the forged operation and returns the forged operation+signature payload to be injected.","ref":"Tezex.Rpc.html#forge_and_sign_operation/2"},{"type":"function","title":"Tezex.Rpc.get_balance/2","doc":"","ref":"Tezex.Rpc.html#get_balance/2"},{"type":"function","title":"Tezex.Rpc.get_block/2","doc":"","ref":"Tezex.Rpc.html#get_block/2"},{"type":"function","title":"Tezex.Rpc.get_block_at_offset/2","doc":"","ref":"Tezex.Rpc.html#get_block_at_offset/2"},{"type":"function","title":"Tezex.Rpc.get_counter_for_account/2","doc":"","ref":"Tezex.Rpc.html#get_counter_for_account/2"},{"type":"function","title":"Tezex.Rpc.get_next_counter_for_account/2","doc":"","ref":"Tezex.Rpc.html#get_next_counter_for_account/2"},{"type":"function","title":"Tezex.Rpc.inject_operation/2","doc":"","ref":"Tezex.Rpc.html#inject_operation/2"},{"type":"function","title":"Tezex.Rpc.preapply_operation/4","doc":"Simulate the application of the operations with the context of the given block and return the result of each operation application.","ref":"Tezex.Rpc.html#preapply_operation/4"},{"type":"function","title":"Tezex.Rpc.prepare_operation/4","doc":"","ref":"Tezex.Rpc.html#prepare_operation/4"},{"type":"function","title":"Tezex.Rpc.send_operation/5","doc":"Send an operation to a Tezos RPC node.","ref":"Tezex.Rpc.html#send_operation/5"},{"type":"type","title":"Tezex.Rpc.encoded_private_key/0","doc":"","ref":"Tezex.Rpc.html#t:encoded_private_key/0"},{"type":"type","title":"Tezex.Rpc.operation/0","doc":"","ref":"Tezex.Rpc.html#t:operation/0"},{"type":"type","title":"Tezex.Rpc.preapplied_operations/0","doc":"","ref":"Tezex.Rpc.html#t:preapplied_operations/0"},{"type":"type","title":"Tezex.Rpc.t/0","doc":"","ref":"Tezex.Rpc.html#t:t/0"},{"type":"type","title":"Tezex.Rpc.transaction/0","doc":"","ref":"Tezex.Rpc.html#t:transaction/0"},{"type":"module","title":"Tezex.Zarith","doc":"Provides encoding and decoding functions for Zarith numbers.\n\nA Zarith number is an integer encoded as a variable length sequence of bytes.\n\nEach byte has a running unary size bit:\n  - The most significant bit of each byte tells if this is the last byte in the sequence (0) or if there is more to read (1)\n  - The second most significant bit of the first byte is reserved for the sign (positive if zero)\n\nSize and sign bits ignored, data is then the binary representation of the absolute value of the number in little endian order.","ref":"Tezex.Zarith.html"},{"type":"function","title":"Tezex.Zarith.consume/1","doc":"Consumes a Zarith-encoded integer.\n\nTakes a hexadecimal string and returns the decoded integer in base 10 along with how many characters of the input string\nwere used to decode the integer.","ref":"Tezex.Zarith.html#consume/1"},{"type":"function","title":"Parameters - Tezex.Zarith.consume/1","doc":"* `binary_input` - A hexadecimal string representing the Zarith-encoded integer.","ref":"Tezex.Zarith.html#consume/1-parameters"},{"type":"function","title":"Returns - Tezex.Zarith.consume/1","doc":"A tuple containing:\n  - A map with the key `:int` and the decoded integer as a string value.\n  - The number of characters consumed from the input string.","ref":"Tezex.Zarith.html#consume/1-returns"},{"type":"function","title":"Examples - Tezex.Zarith.consume/1","doc":"iex> Tezex.Zarith.consume(\"a1d22c\")\n    {%{int: \"365729\"}, 6}\n\n    iex> Tezex.Zarith.consume(\"e1d22c\")\n    {%{int: \"-365729\"}, 6}","ref":"Tezex.Zarith.html#consume/1-examples"},{"type":"function","title":"Tezex.Zarith.decode/1","doc":"Decodes a Zarith-encoded integer.\n\nTakes a hexadecimal string representation of a Zarith-encoded number and returns the integer in base 10.","ref":"Tezex.Zarith.html#decode/1"},{"type":"function","title":"Parameters - Tezex.Zarith.decode/1","doc":"* `binary_input` - A hexadecimal string representing the Zarith-encoded integer.","ref":"Tezex.Zarith.html#decode/1-parameters"},{"type":"function","title":"Returns - Tezex.Zarith.decode/1","doc":"The decoded integer.","ref":"Tezex.Zarith.html#decode/1-returns"},{"type":"function","title":"Examples - Tezex.Zarith.decode/1","doc":"iex> Tezex.Zarith.decode(\"a1d22c\")\n    365_729\n\n    iex> Tezex.Zarith.decode(\"e1d22c\")\n    -365_729","ref":"Tezex.Zarith.html#decode/1-examples"},{"type":"function","title":"Tezex.Zarith.encode/1","doc":"Encodes an integer to a Zarith-encoded hexadecimal string.\n\nTakes an integer in base 10 and returns the Zarith-encoded hexadecimal string.\n\nImplementation based on [anchorageoss/tezosprotocol (MIT License - Copyright (c) 2019 Anchor Labs, Inc.)](https://github.com/anchorageoss/tezosprotocol/blob/23a051d34fcfda8393940141f8151113a1aca10b/zarith/zarith.go#L153)","ref":"Tezex.Zarith.html#encode/1"},{"type":"function","title":"Parameters - Tezex.Zarith.encode/1","doc":"* `integer` - The integer to be encoded.","ref":"Tezex.Zarith.html#encode/1-parameters"},{"type":"function","title":"Returns - Tezex.Zarith.encode/1","doc":"A hexadecimal string representing the Zarith-encoded integer.","ref":"Tezex.Zarith.html#encode/1-returns"},{"type":"function","title":"Examples - Tezex.Zarith.encode/1","doc":"iex> Tezex.Zarith.encode(365_729)\n    \"a1d22c\"\n\n    iex> Tezex.Zarith.encode(-365_729)\n    \"e1d22c\"","ref":"Tezex.Zarith.html#encode/1-examples"},{"type":"type","title":"Tezex.Zarith.decoded_zarith/0","doc":"Represents a decoded Zarith number as an Elixir integer.","ref":"Tezex.Zarith.html#t:decoded_zarith/0"},{"type":"type","title":"Tezex.Zarith.zarith_hex/0","doc":"Represents a Zarith-encoded integer as a hexadecimal string.","ref":"Tezex.Zarith.html#t:zarith_hex/0"},{"type":"extras","title":"Tezex","doc":"# Tezex\n[![Build Status](https://img.shields.io/github/actions/workflow/status/objkt-com/tezex/elixir.yml?branch=main)](https://github.com/objkt-com/tezex/actions) [![Hex.pm Version](https://img.shields.io/hexpm/v/tezex.svg)](https://hex.pm/packages/tezex) [![Documentation](https://img.shields.io/badge/docs-latest-blue.svg)](https://hexdocs.pm/tezex/)\n\nA collection of utils to work with the Tezos blockchain using Elixir: parsing Micheline, verifying Tezos signed messages, deriving Tezos wallet addresses from public key, etc.\n\nRead the documentation on [hexdocs](https://hexdocs.pm/tezex/).\n\nThis lib contains a full, pure Elixir implementation of [HMAC-DRBG](https://hexdocs.pm/tezex/Tezex.Crypto.HMACDRBG.html), tested with [NIST CAPV](https://csrc.nist.gov/projects/cryptographic-algorithm-validation-program) fixtures. We might extract it to a separate lib in the future.\n\nSince what this lib provides is so far limited to what we need at [objkt.com](https://objkt.com), external contributions are most welcome.\nFor instance if you need to sign messages or transactions with a passphrase-protected private key, or translating Micheline to hex, we'd love to collaborate on a PR.","ref":"readme.html"},{"type":"extras","title":"Installation - Tezex","doc":"The package can be installed by adding `tezex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tezex, \"~> 2.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Requirements - Tezex","doc":"OTP24 or above, it needs an elixir version that uses OTP 24 or above, for instance\n\n```\nelixir 1.14.3-otp-25\nerlang 25.2.3\n```\n\nor\n\n```\nelixir 1.13.3-otp-24\nerlang 24.3.4\n```","ref":"readme.html#requirements"},{"type":"extras","title":"Test - Tezex","doc":"```sh\n$ mix test\n$ mix test.watch\n$ mix coveralls.html\n```","ref":"readme.html#test"},{"type":"extras","title":"Generate Documentation - Tezex","doc":"```sh\n$ mix docs\n```","ref":"readme.html#generate-documentation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}